# Gpns
Simple tool for test firebase notification.

### Send notification
```python
gpns send --t <FIREBASE_TOKEN> --c <CREDENTIAL.JSON> --n <NOTIFICATION.json>
```

### Send notification from workspace 
```python
gpns send --t <FIREBASE_TOKEN>
```